@@ -4,12 +4,11 @@ package Plack::Middleware::Throttle::Lite::Backend::Redis;
 
 use strict;
 use warnings;
-use feature ':5.10';
 use Carp ();
 use parent 'Plack::Middleware::Throttle::Lite::Backend::Abstract';
 use Redis 1.955;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
 
 __PACKAGE__->mk_attrs(qw(redis rdb));
@@ -37,9 +36,8 @@ sub init {
 
     $self->rdb($args->{database} || 0);
 
-    my $_handle;
-    eval { $_handle = Redis->new(%options) };
-    $croak->("Cannot get redis handle: $@") if $@;
+    my $_handle = eval { Redis->new(%options) };
+    $croak->("Cannot get redis handle: ". ($@ || $instance->{thru})) unless ref($_handle) eq 'Redis';
 
     $self->redis($_handle);
 }
@@ -96,7 +94,7 @@ Plack::Middleware::Throttle::Lite::Backend::Redis - Redis-driven storage backend
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
